@@ -1,14 +1,16 @@
-use Algorithm::Networksort ':all';
+use Algorithm::Networksort;
 
-my $inputs = $ARGV[0] || 8;
+#
+# Basically do ad-hoc what abecedarian.t does.
+#
+my $inputs = $ARGV[0] || 6;
 my $alg = $ARGV[1] || 'hibbard';
 
-my @network = nw_comparators($inputs, algorithm => $alg);
+my $nw = nwsrt(inputs => $inputs, algorithm => $alg);
 
-print STDERR nw_format(\@network), "\n";
+print STDERR $nw->formatted(), "\n";
 
-print nw_graph(\@network, $inputs, graph => 'text'), "\tN= $inputs\n",
-	"\n\n\n\ttesting...\n";
+print $nw->graph_text(), $nw->title(), "\n\n\n\ttesting...\n";
 
 #
 # Now test using an array of all of the binary combinations, skipping
@@ -19,7 +21,7 @@ foreach my $x (1 .. (1 << $inputs) - 2)
 	my @bitlist = (split(//, unpack("B32", pack("N", $x))))[32 - $inputs .. 31];
 	my $bitstring = join "", @bitlist;
 
-	nw_sort(\@network, \@bitlist);
+	$nw->sort(\@bitlist);
 
 	my $sort_bits = join "", @bitlist;
 
